summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoChild.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoChild.h')
-rw-r--r--lib/kofficecore/KoChild.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/kofficecore/KoChild.h b/lib/kofficecore/KoChild.h
index 0dbc74be..b7285deb 100644
--- a/lib/kofficecore/KoChild.h
+++ b/lib/kofficecore/KoChild.h
@@ -26,7 +26,7 @@
/**
* KoChild is an abstract base class that represents the tqgeometry
* associated with an embedded document. In general it handles its position
* relative to the embedded document's tqparent.
*
* In detail it handles size, matrix operations and can give you
* a clip region. It can deal with scaling, rotation etc. because it
@@ -56,7 +56,7 @@ public:
enum Gadget { NoGadget, TopLeft, TopMid, TopRight, MidLeft, MidRight,
BottomLeft, BottomMid, BottomRight, Move };
- KoChild( TQObject *tqparent = 0, const char *name = 0 );
+ KoChild( TQObject *parent = 0, const char *name = 0 );
virtual ~KoChild();
/**
@@ -69,7 +69,7 @@ public:
* @return the rectangle that would be used to display this
* child document if the child is not rotated or
* subject to some other geometric transformation.
* The rectangle is in the coordinate system of the tqparent,
* using unzoomed coordinates in points.
*
* @see #setGeometry
@@ -78,7 +78,7 @@ public:
/**
* @return the region of this child part relative to the
* coordinate system of the tqparent.
* The region is transformed with the passed
* matrix.
*/
@@ -86,7 +86,7 @@ public:
/**
* @return the polygon which surrounds the child part. The points
* are in coordinates of the tqparent.
* The points are transformed with the
* passed matrix.
*/
@@ -94,14 +94,14 @@ public:
/**
* Tests whether the part contains a certain point. The point is
* in the coordinate system of the tqparent.
*/
//virtual bool contains( const TQPoint& ) const;
/**
* @return the effective bounding rect after all transformations.
* The coordinates of the rectangle are in the coordinate system
- * of the tqparent.
+ * of the parent.
*/
TQRect boundingRect() const;
@@ -26,7 +26,7 @@
* KoChild is an abstract base class that represents the tqgeometry
* associated with an embedded document. In general it handles its position
- * relative to the embedded document's tqparent.
+ * relative to the embedded document's parent.
*
* In detail it handles size, matrix operations and can give you
@@ -69,7 +69,7 @@ public:
* child document if the child is not rotated or
* subject to some other geometric transformation.
- * The rectangle is in the coordinate system of the tqparent,
+ * The rectangle is in the coordinate system of the parent,
* using unzoomed coordinates in points.
*
@@ -78,7 +78,7 @@ public:
/**
* @return the region of this child part relative to the
- * coordinate system of the tqparent.
+ * coordinate system of the parent.
* The region is transformed with the passed
* matrix.
@@ -86,7 +86,7 @@ public:
/**
* @return the polygon which surrounds the child part. The points
- * are in coordinates of the tqparent.
+ * are in coordinates of the parent.
* The points are transformed with the
* passed matrix.
@@ -94,14 +94,14 @@ public:
/**
* Tests whether the part contains a certain point. The point is
- * in the coordinate system of the tqparent.
+ * in the coordinate system of the parent.
*/
//virtual bool contains( const TQPoint& ) const;